[asterisk-commits] branch oej/multiparking - r8442 in /team/oej/multiparking: ./ apps/ channels/...

asterisk-commits at lists.digium.com asterisk-commits at lists.digium.com
Sun Jan 22 11:28:13 MST 2006


Author: oej
Date: Sun Jan 22 12:28:00 2006
New Revision: 8442

URL: http://svn.digium.com/view/asterisk?rev=8442&view=rev
Log:
Updates

Modified:
    team/oej/multiparking/   (props changed)
    team/oej/multiparking/apps/app_meetme.c
    team/oej/multiparking/apps/app_sms.c
    team/oej/multiparking/channels/chan_agent.c
    team/oej/multiparking/channels/chan_iax2.c
    team/oej/multiparking/channels/chan_local.c
    team/oej/multiparking/channels/chan_zap.c
    team/oej/multiparking/config.c
    team/oej/multiparking/configs/zapata.conf.sample
    team/oej/multiparking/devicestate.c
    team/oej/multiparking/enum.c
    team/oej/multiparking/logger.c
    team/oej/multiparking/res/res_features.c
    team/oej/multiparking/udptl.c

Propchange: team/oej/multiparking/
------------------------------------------------------------------------------
--- svnmerge-integrated (original)
+++ svnmerge-integrated Sun Jan 22 12:28:00 2006
@@ -1,1 +1,1 @@
-/trunk:1-8297
+/trunk:1-8335

Modified: team/oej/multiparking/apps/app_meetme.c
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/apps/app_meetme.c?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================
--- team/oej/multiparking/apps/app_meetme.c (original)
+++ team/oej/multiparking/apps/app_meetme.c Sun Jan 22 12:28:00 2006
@@ -1817,7 +1817,7 @@
 	return cnf;
 }
 
-/*--- count_exec: The MeetmeCount application */
+/*! \brief The MeetmeCount application */
 static int count_exec(struct ast_channel *chan, void *data)
 {
 	struct localuser *u;
@@ -1867,7 +1867,7 @@
 	return res;
 }
 
-/*--- conf_exec: The meetme() application */
+/*! \brief The meetme() application */
 static int conf_exec(struct ast_channel *chan, void *data)
 {
 	int res=-1;
@@ -2137,7 +2137,7 @@
 	return NULL;
 }
 
-/*--- admin_exec: The MeetMeadmin application */
+/*! \brief The MeetMeadmin application */
 /* MeetMeAdmin(confno, command, caller) */
 static int admin_exec(struct ast_channel *chan, void *data) {
 	char *params;

Modified: team/oej/multiparking/apps/app_sms.c
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/apps/app_sms.c?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================
--- team/oej/multiparking/apps/app_sms.c (original)
+++ team/oej/multiparking/apps/app_sms.c Sun Jan 22 12:28:00 2006
@@ -198,7 +198,7 @@
 
 static void sms_messagetx (sms_t * h);
 
-/*--- numcpy: copy number, skipping non digits apart from leading + */
+/*! \brief copy number, skipping non digits apart from leading + */
 static void numcpy (char *d, char *s)
 {
 	if (*s == '+')
@@ -211,7 +211,7 @@
 	*d = 0;
 }
 
-/*--- isodate: static, return a date/time in ISO format */
+/*! \brief static, return a date/time in ISO format */
 static char * isodate (time_t t)
 {
 	static char date[20];
@@ -219,7 +219,7 @@
 	return date;
 }
 
-/*--- utf8decode: reads next UCS character from null terminated UTF-8 string and advanced pointer */
+/*! \brief reads next UCS character from null terminated UTF-8 string and advanced pointer */
 /* for non valid UTF-8 sequences, returns character as is */
 /* Does not advance pointer for null termination */
 static long utf8decode (unsigned char **pp)
@@ -265,7 +265,7 @@
 	return *p;                   /* not sensible */
 }
 
-/*--- packsms7: takes a binary header (udhl bytes at udh) and UCS-2 message (udl characters at ud) and packs in to o using SMS 7 bit character codes */
+/*! \brief takes a binary header (udhl bytes at udh) and UCS-2 message (udl characters at ud) and packs in to o using SMS 7 bit character codes */
 /* The return value is the number of septets packed in to o, which is internally limited to SMSLEN */
 /* o can be null, in which case this is used to validate or count only */
 /* if the input contains invalid characters then the return value is -1 */
@@ -335,7 +335,7 @@
 	return n;
 }
 
-/*--- packsms8: takes a binary header (udhl bytes at udh) and UCS-2 message (udl characters at ud) and packs in to o using 8 bit character codes */
+/*! \brief takes a binary header (udhl bytes at udh) and UCS-2 message (udl characters at ud) and packs in to o using 8 bit character codes */
 /* The return value is the number of bytes packed in to o, which is internally limited to 140 */
 /* o can be null, in which case this is used to validate or count only */
 /* if the input contains invalid characters then the return value is -1 */
@@ -367,7 +367,7 @@
 	return p;
 }
 
-/*--- packsms16: takes a binary header (udhl bytes at udh) and UCS-2 
+/*! \brief takes a binary header (udhl bytes at udh) and UCS-2 
 	message (udl characters at ud) and packs in to o using 16 bit 
 	UCS-2 character codes 
 	The return value is the number of bytes packed in to o, which is 
@@ -404,7 +404,7 @@
 	return p;
 }
 
-/*--- packsms: general pack, with length and data, 
+/*! \brief general pack, with length and data, 
 	returns number of bytes of target used */
 static int packsms (unsigned char dcs, unsigned char *base, unsigned int udhl, unsigned char *udh, int udl, unsigned short *ud)
 {
@@ -436,7 +436,7 @@
 }
 
 
-/*--- packdate: pack a date and return */
+/*! \brief pack a date and return */
 static void packdate (unsigned char *o, time_t w)
 {
 	struct tm *t = localtime (&w);
@@ -457,7 +457,7 @@
 		*o++ = ((z % 10) << 4) + z / 10;
 }
 
-/*--- unpackdate: unpack a date and return */
+/*! \brief unpack a date and return */
 static time_t unpackdate (unsigned char *i)
 {
 	struct tm t;
@@ -475,7 +475,7 @@
 	return mktime (&t);
 }
 
-/*--- unpacksms7: unpacks bytes (7 bit encoding) at i, len l septets, 
+/*! \brief unpacks bytes (7 bit encoding) at i, len l septets, 
 	and places in udh and ud setting udhl and udl. udh not used 
 	if udhi not set */
 static void unpacksms7 (unsigned char *i, unsigned char l, unsigned char *udh, int *udhl, unsigned short *ud, int *udl, char udhi)
@@ -526,7 +526,7 @@
 	*udl = (o - ud);
 }
 
-/*--- unpacksms8: unpacks bytes (8 bit encoding) at i, len l septets, 
+/*! \brief unpacks bytes (8 bit encoding) at i, len l septets, 
       and places in udh and ud setting udhl and udl. udh not used 
       if udhi not set */
 static void unpacksms8 (unsigned char *i, unsigned char l, unsigned char *udh, int *udhl, unsigned short *ud, int *udl, char udhi)
@@ -551,7 +551,7 @@
 	*udl = (o - ud);
 }
 
-/*--- unpacksms16: unpacks bytes (16 bit encoding) at i, len l septets,
+/*! \brief unpacks bytes (16 bit encoding) at i, len l septets,
 	 and places in udh and ud setting udhl and udl. 
 	udh not used if udhi not set */
 static void unpacksms16 (unsigned char *i, unsigned char l, unsigned char *udh, int *udhl, unsigned short *ud, int *udl, char udhi)
@@ -580,7 +580,7 @@
 	*udl = (o - ud);
 }
 
-/*--- unpacksms: general unpack - starts with length byte (octet or septet) and returns number of bytes used, inc length */
+/*! \brief general unpack - starts with length byte (octet or septet) and returns number of bytes used, inc length */
 static int unpacksms (unsigned char dcs, unsigned char *i, unsigned char *udh, int *udhl, unsigned short *ud, int *udl, char udhi)
 {
 	int l = *i++;
@@ -594,7 +594,7 @@
 	return l + 1;
 }
 
-/*--- unpackaddress: unpack an address from i, return byte length, unpack to o */
+/*! \brief unpack an address from i, return byte length, unpack to o */
 static unsigned char unpackaddress (char *o, unsigned char *i)
 {
 	unsigned char l = i[0],
@@ -611,7 +611,7 @@
 	return (l + 5) / 2;
 }
 
-/*--- packaddress: store an address at o, and return number of bytes used */
+/*! \brief store an address at o, and return number of bytes used */
 static unsigned char packaddress (unsigned char *o, char *i)
 {
 	unsigned char p = 2;
@@ -636,7 +636,7 @@
 	return p;
 }
 
-/*--- sms_log: Log the output, and remove file */
+/*! \brief Log the output, and remove file */
 static void sms_log (sms_t * h, char status)
 {
 	if (*h->oa || *h->da) {
@@ -674,7 +674,7 @@
 	}
 }
 
-/*--- sms_readfile: parse and delete a file */
+/*! \brief parse and delete a file */
 static void sms_readfile (sms_t * h, char *fn)
 {
 	char line[1000];
@@ -856,7 +856,7 @@
 	}
 }
 
-/*--- sms_writefile: white a received text message to a file */
+/*! \brief white a received text message to a file */
 static void sms_writefile (sms_t * h)
 {
 	char fn[200] = "", fn2[200] = "";
@@ -943,7 +943,7 @@
 	}
 }
 
-/*--- readdirqueue: read dir skipping dot files... */
+/*! \brief read dir skipping dot files... */
 static struct dirent *readdirqueue (DIR * d, char *queue)
 {
    struct dirent *f;
@@ -953,7 +953,7 @@
    return f;
 }
 
-/*--- sms_handleincoming: handle the incoming message */
+/*! \brief handle the incoming message */
 static unsigned char sms_handleincoming (sms_t * h)
 {
 	unsigned char p = 3;
@@ -1024,8 +1024,7 @@
 #define NAME_MAX 1024
 #endif
 
-/*--- sms_nextoutgoing: find and fill in next message, 
-	or send a REL if none waiting */
+/*! \brief find and fill in next message, or send a REL if none waiting */
 static void sms_nextoutgoing (sms_t * h)
 {          
 	char fn[100 + NAME_MAX] = "";

Modified: team/oej/multiparking/channels/chan_agent.c
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/channels/chan_agent.c?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================
--- team/oej/multiparking/channels/chan_agent.c (original)
+++ team/oej/multiparking/channels/chan_agent.c Sun Jan 22 12:28:00 2006
@@ -940,7 +940,7 @@
 	return ret;
 }
 
-/*--- agent_new: Create new agent channel ---*/
+/*! \brief Create new agent channel ---*/
 static struct ast_channel *agent_new(struct agent_pvt *p, int state)
 {
 	struct ast_channel *tmp;
@@ -1305,7 +1305,7 @@
 	return -1;
 }
 
-/*--- agent_request: Part of the Asterisk PBX interface ---*/
+/*! \brief Part of the Asterisk PBX interface ---*/
 static struct ast_channel *agent_request(const char *type, int format, void *data, int *cause)
 {
 	struct agent_pvt *p;
@@ -2434,7 +2434,7 @@
 	}
 }
 
-/*--- agent_devicestate: Part of PBX channel interface ---*/
+/*! \brief Part of PBX channel interface ---*/
 static int agent_devicestate(void *data)
 {
 	struct agent_pvt *p;

Modified: team/oej/multiparking/channels/chan_iax2.c
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/channels/chan_iax2.c?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================
--- team/oej/multiparking/channels/chan_iax2.c (original)
+++ team/oej/multiparking/channels/chan_iax2.c Sun Jan 22 12:28:00 2006
@@ -1915,7 +1915,7 @@
 	return res;
 }
 
-/*--- iax2_show_peer: Show one peer in detail ---*/
+/*! \brief Show one peer in detail */
 static int iax2_show_peer(int fd, int argc, char *argv[])
 {
 	char status[30];
@@ -3378,7 +3378,7 @@
 	return res;
 }
 
-/*--- ast_iax2_new: Create new call, interface with the PBX core */
+/*! \brief  Create new call, interface with the PBX core */
 static struct ast_channel *ast_iax2_new(int callno, int state, int capability)
 {
 	struct ast_channel *tmp;
@@ -4900,6 +4900,8 @@
 	fh.iseqno = 0;
 	fh.type = AST_FRAME_IAX;
 	fh.csub = compress_subclass(IAX_COMMAND_INVAL);
+	if (iaxdebug)
+		 iax_showframe(NULL, &fh, 0, sin, 0);
 #if 0
 	if (option_debug)
 #endif	
@@ -6765,6 +6767,10 @@
 					break;
 				if (ies.provverpres && ies.serviceident && sin.sin_addr.s_addr)
 					check_provisioning(&sin, fd, ies.serviceident, ies.provver);
+				/* If we're in trunk mode, do it now, and update the trunk number in our frame before continuing */
+				if (ast_test_flag(iaxs[fr.callno], IAX_TRUNK)) {
+					fr.callno = make_trunk(fr.callno, 1);
+				}
 				/* For security, always ack immediately */
 				if (delayreject)
 					send_command_immediate(iaxs[fr.callno], AST_FRAME_IAX, IAX_COMMAND_ACK, fr.ts, NULL, 0,fr.iseqno);
@@ -6774,10 +6780,6 @@
 					if (authdebug)
 						ast_log(LOG_NOTICE, "Rejected connect attempt from %s, who was trying to reach '%s@%s'\n", ast_inet_ntoa(iabuf, sizeof(iabuf), sin.sin_addr), iaxs[fr.callno]->exten, iaxs[fr.callno]->context);
 					break;
-				}
-				/* If we're in trunk mode, do it now, and update the trunk number in our frame before continuing */
-				if (ast_test_flag(iaxs[fr.callno], IAX_TRUNK)) {
-					fr.callno = make_trunk(fr.callno, 1);
 				}
 				/* This might re-enter the IAX code and need the lock */
 				if (strcasecmp(iaxs[fr.callno]->exten, "TBD")) {
@@ -8005,11 +8007,8 @@
 }
 
 
-/*--- check_src_ip: Check if address can be used as packet source.
- returns:
- 0  address available
- 1  address unavailable
--1  error
+/*! \brief Check if address can be used as packet source.
+ \return 0  address available, 1  address unavailable, -1  error
 */
 static int check_srcaddr(struct sockaddr *sa, socklen_t salen)
 {
@@ -8033,7 +8032,7 @@
 	return 0;
 }
 
-/*--- peer_set_srcaddr: Parse the "sourceaddress" value,
+/*! \brief Parse the "sourceaddress" value,
   lookup in netsock list and set peer's sockfd. Defaults to defaultsockfd if
   not found. */
 static int peer_set_srcaddr(struct iax2_peer *peer, const char *srcaddr)
@@ -8091,7 +8090,7 @@
 }
 
 		
-/*--- build_peer: Create peer structure based on configuration */
+/*! \brief Create peer structure based on configuration */
 static struct iax2_peer *build_peer(const char *name, struct ast_variable *v, int temponly)
 {
 	struct iax2_peer *peer;
@@ -8282,7 +8281,7 @@
 	return peer;
 }
 
-/*--- build_user: Create in-memory user structure from configuration */
+/*! \brief Create in-memory user structure from configuration */
 static struct iax2_user *build_user(const char *name, struct ast_variable *v, int temponly)
 {
 	struct iax2_user *prev, *user;
@@ -8564,7 +8563,7 @@
 }
 
 
-/*--- set_config: Load configuration */
+/*! \brief Load configuration */
 static int set_config(char *config_file, int reload)
 {
 	struct ast_config *cfg;
@@ -9064,7 +9063,7 @@
 	return dp;	
 }
 
-/*--- iax2_exists: Part of the IAX2 switch interface ---*/
+/*! \brief Part of the IAX2 switch interface */
 static int iax2_exists(struct ast_channel *chan, const char *context, const char *exten, int priority, const char *callerid, const char *data)
 {
 	struct iax2_dpcache *dp;
@@ -9087,7 +9086,7 @@
 	return res;
 }
 
-/*--- iax2_canmatch: part of the IAX2 dial plan switch interface */
+/*! \brief part of the IAX2 dial plan switch interface */
 static int iax2_canmatch(struct ast_channel *chan, const char *context, const char *exten, int priority, const char *callerid, const char *data)
 {
 	int res = 0;
@@ -9110,7 +9109,7 @@
 	return res;
 }
 
-/*--- iax2_matchmore: Part of the IAX2 Switch interface */
+/*! \brief Part of the IAX2 Switch interface */
 static int iax2_matchmore(struct ast_channel *chan, const char *context, const char *exten, int priority, const char *callerid, const char *data)
 {
 	int res = 0;
@@ -9133,7 +9132,7 @@
 	return res;
 }
 
-/*--- iax2_exec: Execute IAX2 dialplan switch */
+/*! \brief Execute IAX2 dialplan switch */
 static int iax2_exec(struct ast_channel *chan, const char *context, const char *exten, int priority, const char *callerid, int newstack, const char *data)
 {
 	char odata[256];
@@ -9274,7 +9273,7 @@
 };
 
 
-/*--- iax2_devicestate: Part of the device state notification system ---*/
+/*! \brief Part of the device state notification system ---*/
 static int iax2_devicestate(void *data) 
 {
 	char *dest = (char *) data;
@@ -9516,7 +9515,7 @@
 }
 
 
-/*--- load_module: Load IAX2 module, load configuraiton ---*/
+/*! \brief Load IAX2 module, load configuraiton ---*/
 int load_module(void)
 {
 	char *config = "iax.conf";

Modified: team/oej/multiparking/channels/chan_local.c
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/channels/chan_local.c?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================
--- team/oej/multiparking/channels/chan_local.c (original)
+++ team/oej/multiparking/channels/chan_local.c Sun Jan 22 12:28:00 2006
@@ -316,8 +316,8 @@
 	return res;
 }
 
-/*--- local_call: Initiate new call, part of PBX interface */
-/* 	dest is the dial string */
+/*! \brief Initiate new call, part of PBX interface 
+ * 	dest is the dial string */
 static int local_call(struct ast_channel *ast, char *dest, int timeout)
 {
 	struct local_pvt *p = ast->tech_pvt;
@@ -381,7 +381,7 @@
 }
 #endif
 
-/*--- local_hangup: Hangup a call through the local proxy channel */
+/*! \brief Hangup a call through the local proxy channel */
 static int local_hangup(struct ast_channel *ast)
 {
 	struct local_pvt *p = ast->tech_pvt;
@@ -452,7 +452,7 @@
 	return 0;
 }
 
-/*--- local_alloc: Create a call structure */
+/*! \brief Create a call structure */
 static struct local_pvt *local_alloc(char *data, int format)
 {
 	struct local_pvt *tmp;
@@ -495,7 +495,7 @@
 	return tmp;
 }
 
-/*--- local_new: Start new local channel */
+/*! \brief Start new local channel */
 static struct ast_channel *local_new(struct local_pvt *p, int state)
 {
 	struct ast_channel *tmp, *tmp2;
@@ -548,7 +548,7 @@
 }
 
 
-/*--- local_request: Part of PBX interface */
+/*! \brief Part of PBX interface */
 static struct ast_channel *local_request(const char *type, int format, void *data, int *cause)
 {
 	struct local_pvt *p;
@@ -560,7 +560,7 @@
 	return chan;
 }
 
-/*--- locals_show: CLI command "local show channels" */
+/*! \brief CLI command "local show channels" */
 static int locals_show(int fd, int argc, char **argv)
 {
 	struct local_pvt *p;
@@ -589,7 +589,7 @@
 	{ "local", "show", "channels", NULL }, locals_show, 
 	"Show status of local channels", show_locals_usage, NULL };
 
-/*--- load_module: Load module into PBX, register channel */
+/*! \brief Load module into PBX, register channel */
 int load_module()
 {
 	/* Make sure we can register our channel type */
@@ -601,13 +601,13 @@
 	return 0;
 }
 
-/*--- reload: Reload module */
+/*! \brief Reload module */
 int reload()
 {
 	return 0;
 }
 
-/*--- unload_module: Unload the local proxy channel from Asterisk */
+/*! \brief Unload the local proxy channel from Asterisk */
 int unload_module()
 {
 	struct local_pvt *p;

Modified: team/oej/multiparking/channels/chan_zap.c
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/channels/chan_zap.c?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================
--- team/oej/multiparking/channels/chan_zap.c (original)
+++ team/oej/multiparking/channels/chan_zap.c Sun Jan 22 12:28:00 2006
@@ -33,6 +33,8 @@
  * \arg \ref Config_zap
  *
  * \ingroup channel_drivers
+ *
+ * \todo Decprecate the "musiconhold" configuration option in v1.5dev
  */
 
 #include <stdio.h>
@@ -10533,7 +10535,7 @@
 			ast_copy_string(language, v->value, sizeof(language));
 		} else if (!strcasecmp(v->name, "progzone")) {
 			ast_copy_string(progzone, v->value, sizeof(progzone));
-		} else if (!strcasecmp(v->name, "musiconhold")) {
+		} else if (!strcasecmp(v->name, "musiconhold") || !strcasecmp(v->name, "musicclass")) {
 			ast_copy_string(musicclass, v->value, sizeof(musicclass));
 		} else if (!strcasecmp(v->name, "parkinglot")) {
 			ast_copy_string(parkinglot, v->value, sizeof(parkinglot));

Modified: team/oej/multiparking/config.c
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/config.c?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================
--- team/oej/multiparking/config.c (original)
+++ team/oej/multiparking/config.c Sun Jan 22 12:28:00 2006
@@ -898,7 +898,7 @@
 	return 0;
 }
 
-/*--- find_engine: Find realtime engine for realtime family */
+/*! \brief Find realtime engine for realtime family */
 static struct ast_config_engine *find_engine(const char *family, char *database, int dbsiz, char *table, int tabsiz) 
 {
 	struct ast_config_engine *eng, *ret = NULL;
@@ -1008,7 +1008,7 @@
 	return res;
 }
 
-/*--- ast_check_realtime: Check if realtime engine is configured for family */
+/*! \brief Check if realtime engine is configured for family */
 int ast_check_realtime(const char *family)
 {
 	struct ast_config_engine *eng;

Modified: team/oej/multiparking/configs/zapata.conf.sample
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/configs/zapata.conf.sample?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================
--- team/oej/multiparking/configs/zapata.conf.sample (original)
+++ team/oej/multiparking/configs/zapata.conf.sample Sun Jan 22 12:28:00 2006
@@ -454,7 +454,7 @@
 ; Select which class of music to use for music on hold.  If not specified
 ; then the default will be used.
 ;
-;musiconhold=default
+;musicclass=default
 ;
 ; PRI channels can have an idle extension and a minunused number.  So long as
 ; at least "minunused" channels are idle, chan_zap will try to call "idledial"

Modified: team/oej/multiparking/devicestate.c
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/devicestate.c?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================
--- team/oej/multiparking/devicestate.c (original)
+++ team/oej/multiparking/devicestate.c Sun Jan 22 12:28:00 2006
@@ -71,13 +71,13 @@
 static pthread_t change_thread = AST_PTHREADT_NULL;
 static ast_cond_t change_pending;
 
-/*--- devstate2str: Find devicestate as text message for output */
+/*! \brief Find devicestate as text message for output */
 const char *devstate2str(int devstate) 
 {
 	return devstatestring[devstate];
 }
 
-/*--- ast_parse_device_state: Find out if device is active in a call or not */
+/*! \brief Find out if device is active in a call or not */
 int ast_parse_device_state(const char *device)
 {
 	struct ast_channel *chan;
@@ -101,7 +101,7 @@
 	return res;
 }
 
-/*--- ast_device_state: Check device state through channel specific function or generic function */
+/*! \brief Check device state through channel specific function or generic function */
 int ast_device_state(const char *device)
 {
 	char *buf;
@@ -138,7 +138,7 @@
 	}
 }
 
-/*--- ast_devstate_add: Add device state watcher */
+/*! \brief Add device state watcher */
 int ast_devstate_add(ast_devstate_cb_type callback, void *data)
 {
 	struct devstate_cb *devcb;
@@ -160,7 +160,7 @@
 	return 0;
 }
 
-/*--- ast_devstate_del: Remove device state watcher */
+/*! \brief Remove device state watcher */
 void ast_devstate_del(ast_devstate_cb_type callback, void *data)
 {
 	struct devstate_cb *devcb;
@@ -177,7 +177,7 @@
 	AST_LIST_UNLOCK(&devstate_cbs);
 }
 
-/*--- do_state_change: Notify callback watchers of change, and notify PBX core for hint updates */
+/*! \brief Notify callback watchers of change, and notify PBX core for hint updates */
 static void do_state_change(const char *device)
 {
 	int state;
@@ -232,7 +232,7 @@
 	return __ast_device_state_changed_literal(buf);
 }
 
-/*--- ast_device_state_changed: Accept change notification, add it to change queue */
+/*! \brief Accept change notification, add it to change queue */
 int ast_device_state_changed(const char *fmt, ...) 
 {
 	char buf[AST_MAX_EXTENSION];
@@ -244,7 +244,7 @@
 	return __ast_device_state_changed_literal(buf);
 }
 
-/*--- do_devstate_changes: Go through the dev state change queue and update changes in the dev state thread */
+/*! \brief Go through the dev state change queue and update changes in the dev state thread */
 static void *do_devstate_changes(void *data)
 {
 	struct state_change *cur;
@@ -269,7 +269,7 @@
 	return NULL;
 }
 
-/*--- ast_device_state_engine_init: Initialize the device state engine in separate thread */
+/*! \brief Initialize the device state engine in separate thread */
 int ast_device_state_engine_init(void)
 {
 	pthread_attr_t attr;

Modified: team/oej/multiparking/enum.c
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/enum.c?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================
--- team/oej/multiparking/enum.c (original)
+++ team/oej/multiparking/enum.c Sun Jan 22 12:28:00 2006
@@ -82,7 +82,7 @@
 	unsigned short pref;
 } __attribute__ ((__packed__));
 
-/*--- parse_ie: Parse NAPTR record information elements */
+/*! \brief Parse NAPTR record information elements */
 static int parse_ie(char *data, int maxdatalen, char *src, int srclen)
 {
 	int len, olen;
@@ -100,7 +100,7 @@
 	return olen + 1;
 }
 
-/*--- parse_naptr: Parse DNS NAPTR record used in ENUM ---*/
+/*! \brief Parse DNS NAPTR record used in ENUM ---*/
 static int parse_naptr(char *dst, int dstsize, char *tech, int techsize, char *answer, int len, char *naptrinput)
 {
 
@@ -309,7 +309,7 @@
 	int naptr_rrs_count; /* Size of array naptr_rrs */
 };
 
-/*--- txt_callback: Callback for TXT record lookup */
+/*! \brief Callback for TXT record lookup */
 static int txt_callback(void *context, char *answer, int len, char *fullanswer)
 {
 	struct enum_context *c = (struct enum_context *)context;
@@ -344,7 +344,7 @@
 	return 1;
 }
 
-/*--- enum_callback: Callback from ENUM lookup function */
+/*! \brief Callback from ENUM lookup function */
 static int enum_callback(void *context, char *answer, int len, char *fullanswer)
 {
 	struct enum_context *c = (struct enum_context *)context;
@@ -383,7 +383,7 @@
 	return 0;
 }
 
-/*--- ast_get_enum: ENUM lookup */
+/*! \brief ENUM lookup */
 int ast_get_enum(struct ast_channel *chan, const char *number, char *dst, int dstlen, char *tech, int techlen, char* suffix, char* options)
 {
 	struct enum_context context;
@@ -545,7 +545,7 @@
 	return ret;
 }
 
-/*--- ast_get_txt: Get TXT record from DNS.
+/*! \brief Get TXT record from DNS.
 	Really has nothing to do with enum, but anyway...
  */
 int ast_get_txt(struct ast_channel *chan, const char *number, char *dst, int dstlen, char *tech, int techlen, char *txt, int txtlen)
@@ -608,7 +608,7 @@
 	return ret;
 }
 
-/*--- enum_newtoplev: Add enum tree to linked list ---*/
+/*! \brief Add enum tree to linked list ---*/
 static struct enum_search *enum_newtoplev(char *s)
 {
 	struct enum_search *tmp;
@@ -621,7 +621,7 @@
 	return tmp;
 }
 
-/*--- ast_enum_init: Initialize the ENUM support subsystem */
+/*! \brief Initialize the ENUM support subsystem */
 int ast_enum_init(void)
 {
 	struct ast_config *cfg;

Modified: team/oej/multiparking/logger.c
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/logger.c?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================
--- team/oej/multiparking/logger.c (original)
+++ team/oej/multiparking/logger.c Sun Jan 22 12:28:00 2006
@@ -500,8 +500,7 @@
 		return RESULT_SUCCESS;
 }
 
-/*--- handle_logger_show_channels: CLI command to show logging system 
- 	configuration */
+/*! \brief CLI command to show logging system configuration */
 static int handle_logger_show_channels(int fd, int argc, char *argv[])
 {
 #define FORMATL	"%-35.35s %-8.8s %-9.9s "

Modified: team/oej/multiparking/res/res_features.c
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/res/res_features.c?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================
--- team/oej/multiparking/udptl.c (original)
+++ team/oej/multiparking/udptl.c Sun Jan 22 12:28:00 2006
@@ -4,7 +4,7 @@
  * UDPTL support for T.38
  * 
  * Copyright (C) 2005, Steve Underwood, partly based on RTP code which is
- * Copyright (C) 1999-2004, Digium, Inc.
+ * Copyright (C) 1999-2006, Digium, Inc.
  *
  * Steve Underwood <steveu at coppice.org>
  *
@@ -29,7 +29,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision$")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 8038 $")
 
 #include "asterisk/udptl.h"
 #include "asterisk/frame.h"



More information about the asterisk-commits mailing list
--- team/oej/multiparking/res/res_features.c (original)
+++ team/oej/multiparking/res/res_features.c Sun Jan 22 12:28:00 2006
@@ -34,7 +34,7 @@
 
 /*! \file
  *
  * \brief Routines implementing call features
  *
  * \author Mark Spencer <markster at digium.com> 
  */
@@ -304,16 +304,15 @@
 
 	/* Channel variables override everything */
 
-	temp  = pbx_builtin_getvar_helper(chan, "PARKINGLOT");
-
-	if (temp)
+	if ((temp  = pbx_builtin_getvar_helper(chan, "PARKINGLOT")))
 		return temp;
+
 	return parkinglot;
 }
 
-/*--- ast_park_call: Park a call */
-/* We put the user in the parking list, then wake up the parking 
-	thread to be sure it looks after these channels too */
+/*! \brief Park a call 
+ 	We put the user in the parking list, then wake up the parking thread to be sure it looks
+	after these channels too */
 int ast_park_call_full(struct ast_channel *chan, struct ast_channel *peer, int timeout, int *extout, struct ast_parkinglot *parkinglot)
 {
 	struct parkeduser *pu, *cur;
@@ -927,6 +926,7 @@
 
 /* add atxfer and automon as undefined so you can only use em if you configure them */
 #define FEATURES_COUNT (sizeof(builtin_features) / sizeof(builtin_features[0]))
+
 struct ast_call_feature builtin_features[] = 
  {
 	{ AST_FEATURE_REDIRECT, "Blind Transfer", "blindxfer", "#", "#", builtin_blindtransfer, AST_FEATURE_FLAG_NEEDSDTMF },
@@ -938,7 +938,7 @@
 
 static AST_LIST_HEAD(feature_list,ast_call_feature) feature_list;
 
-/* register new feature into feature_list*/
+/*! \brief register new feature into feature_list*/
 void ast_register_feature(struct ast_call_feature *feature)
 {
 	if (!feature) {
@@ -954,7 +954,7 @@
 		ast_verbose(VERBOSE_PREFIX_2 "Registered Feature '%s'\n",feature->sname);
 }
 
-/* unregister feature from feature_list */
+/*! \brief unregister feature from feature_list */
 void ast_unregister_feature(struct ast_call_feature *feature)
 {
 	if (!feature) return;
@@ -975,7 +975,7 @@
 	AST_LIST_UNLOCK(&feature_list);
 }
 
-/* find a feature by name */
+/*! \brief find a feature by name */
 static struct ast_call_feature *find_feature(char *name)
 {
 	struct ast_call_feature *tmp;
@@ -990,7 +990,7 @@
 	return tmp;
 }
 
-/* exec an app by feature */
+/*! \brief exec an app by feature */
 static int feature_exec_app(struct ast_channel *chan, struct ast_channel *peer, struct ast_bridge_config *config, char *code, int sense)
 {
 	struct ast_app *app;
@@ -2038,7 +2038,7 @@
 static struct ast_cli_entry showparked =
 { { "show", "parkedcalls", NULL }, handle_parkedcalls, "Lists parked calls", showparked_help };
 
-/*--- manager_parking_status: Dump lot status in manager */
+/*! \brief Dump parking lot status in manager */
 static int manager_parking_status( struct mansession *s, struct message *m )
 {
 	struct parkeduser *cur;
@@ -34,7 +34,7 @@
 /*! \file
  *
- * \brief Routines implementing call features
+ * \brief Routines implementing call features as call pickup, parking and transfer
  *
  * \author Mark Spencer <markster at digium.com> 

Modified: team/oej/multiparking/udptl.c
URL: http://svn.digium.com/view/asterisk/team/oej/multiparking/udptl.c?rev=8442&r1=8441&r2=8442&view=diff
==============================================================================